Files
:::::

.. toctree::
   :caption: Files
   :maxdepth: 2

   intro-WorkingwithDataFiles.rst
   FindingaFileonyourDisk.rst
   ReadingaFile.rst
   Iteratingoverlinesinafile.rst
   AlternativeFileReadingMethods.rst
   WritingTextFiles.rst
   WithStatements.rst
   FetchingSomethingFromTheWeb.rst
   Glossary.rst
   Exercises.rst
